//package com.example.testktor
//
//import android.os.Bundle
//import android.util.Log
//import androidx.activity.ComponentActivity
//import androidx.activity.compose.setContent
//import androidx.activity.enableEdgeToEdge
//import androidx.compose.foundation.layout.fillMaxSize
//import androidx.compose.foundation.layout.padding
//import androidx.compose.material3.Scaffold
//import androidx.compose.material3.Text
//import androidx.compose.material3.CircularProgressIndicator
//import androidx.compose.runtime.*
//import androidx.compose.ui.Modifier
//import androidx.compose.ui.tooling.preview.Preview
//import com.example.testktor.ui.theme.TestKtorTheme
//import io.ktor.client.*
//import io.ktor.client.request.*
//import io.ktor.client.engine.android.*
//import io.ktor.client.plugins.contentnegotiation.*
//import io.ktor.client.statement.HttpResponse
//import io.ktor.client.statement.bodyAsText
//import io.ktor.http.ContentType
//import io.ktor.http.contentType
//import kotlinx.coroutines.launch
//import kotlinx.serialization.Serializable
//import io.ktor.serialization.kotlinx.json.*
//import kotlinx.serialization.decodeFromString
//import kotlinx.serialization.json.Json
//
//@Serializable
//data class User(val id: Int, val name: String)
//
//class MainActivity : ComponentActivity() {
//    private val client = HttpClient(Android) {
//        install(ContentNegotiation) {
//            json(Json { prettyPrint = true })
//        }
//    }
//
//    override fun onCreate(savedInstanceState: Bundle?) {
//        super.onCreate(savedInstanceState)
//        enableEdgeToEdge()
//        setContent {
//            TestKtorTheme {
//                Scaffold(modifier = Modifier.fillMaxSize()) { innerPadding ->
//                    UserScreen(modifier = Modifier.padding(innerPadding), client = client)
//                }
//            }
//        }
//    }
//}
//

package com.example.testktor

import android.os.Bundle
import android.util.Log
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.activity.enableEdgeToEdge
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.padding
import androidx.compose.material3.Scaffold
import androidx.compose.material3.Text
import androidx.compose.material3.CircularProgressIndicator
import androidx.compose.runtime.*
import androidx.compose.ui.Modifier
import androidx.compose.ui.tooling.preview.Preview
import androidx.navigation.compose.NavHost
import androidx.navigation.compose.composable
import androidx.navigation.compose.rememberNavController
import com.example.matuletest.ui.auth.FirstScreen
import com.example.matuletest.ui.auth.SliderScreen
import com.example.testktor.auth.AuthScreen
import com.example.testktor.auth.ForgotPasswordScreen
import com.example.testktor.auth.RegScreen
import com.example.testktor.auth.ResetPasswordScreen
//import com.example.testktor.auth.AuthScreen
//import com.example.testktor.auth.RegistrationScreen
import com.example.testktor.ui.theme.TestKtorTheme
import io.ktor.client.*
import io.ktor.client.request.*
import io.ktor.client.engine.android.*
import io.ktor.client.plugins.contentnegotiation.*
import io.ktor.client.statement.HttpResponse
import io.ktor.client.statement.bodyAsText
import io.ktor.http.ContentType
import io.ktor.http.contentType
import kotlinx.coroutines.launch
import kotlinx.serialization.Serializable
import io.ktor.serialization.kotlinx.json.*
import kotlinx.serialization.decodeFromString
import kotlinx.serialization.json.Json

//class MainActivity : ComponentActivity() {
//    private val client = HttpClient(Android) {
//        install(ContentNegotiation) {
//            json(Json { prettyPrint = true })
//        }
//    }
//
//    override fun onCreate(savedInstanceState: Bundle?) {
//        super.onCreate(savedInstanceState)
//        enableEdgeToEdge()
//        setContent {
//            TestKtorTheme {
//                Scaffold(modifier = Modifier.fillMaxSize()) { innerPadding ->
//                    UserScreen(modifier = Modifier.padding(innerPadding), client = client)
//                }
//            }
//        }
//    }
//}

class MainActivity : ComponentActivity() {
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        enableEdgeToEdge()
        setContent {
            TestKtorTheme {
                val navController = rememberNavController()

                NavHost(navController = navController, startDestination = "first_screen") {
                    composable("first_screen") {
                        FirstScreen(onNavigateToSliderScreen = {
                            navController.navigate("slider_screen")
                        })
                    }
                    composable("slider_screen") {
                        SliderScreen(onNavigateToAuthScreen = {
                            navController.navigate("auth_screen")
                        })
                    }
                    composable("auth_screen") {
                        AuthScreen(navController)
                    }
                    composable("registration_screen") {
                        RegScreen(navController)
                    }
                    composable("resetPassword_screen") {
                        ResetPasswordScreen(navController)
                    }
                    composable("forgotPassword_screen") {
                        ForgotPasswordScreen(navController)
                    }
                }
            }
        }
    }
}

