package com.example.testktor.auth

import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.text.ClickableText
import androidx.compose.material3.Button
import androidx.compose.material3.Text
import androidx.compose.material3.TextField
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.collectAsState
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.text.buildAnnotatedString
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.input.PasswordVisualTransformation
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.lifecycle.viewmodel.compose.viewModel
import androidx.navigation.NavController
import com.example.testktor.authUser
import com.example.testktor.regUser
import io.ktor.client.HttpClient
import io.ktor.client.engine.android.Android

@Composable
fun RegScreen(navController: NavController) {
    var regSuccess by remember { mutableStateOf<String?>(null) }
    var email by remember { mutableStateOf("") }
    var password by remember { mutableStateOf("") }
    var name by remember { mutableStateOf("") }

    val client = HttpClient(Android)

    LaunchedEffect(email, password) {
        if (email.isNotEmpty() && password.isNotEmpty()) {
            val result = regUser(client, email, password, name)
            regSuccess = if (result) "Success" else "Failed"
        }
    }

    RegContent(navController, regSuccess, email, password, name) { newEmail, newPassword, newName ->
        email = newEmail
        password = newPassword
        name = newName
    }
}

@Composable
fun RegContent(
    navController: NavController,
    regSuccess: String?,
    email: String,
    password: String,
    name: String,
    onReg: (String, String, String) -> Unit
) {
    var emailIn by remember { mutableStateOf(email) }
    var passwordIn by remember { mutableStateOf(password) }
    var nameIn by remember { mutableStateOf(name) }

    Column(
        modifier = Modifier.fillMaxSize(),
        horizontalAlignment = Alignment.CenterHorizontally,
        verticalArrangement = Arrangement.Center
    ) {
        // Отображение текста "Success" в левом верхнем углу
        if (regSuccess != null){
            if (regSuccess == "Success") {
                Text(
                    text = "Success",
                    modifier = Modifier
                        .padding(start = 16.dp, top = 16.dp)
                        .align(Alignment.Start),
                    color = Color.Green,
                    style = TextStyle(fontSize = 18.sp, fontWeight = FontWeight.Bold)
                )
            } else{
                Text(
                    text = "Error",
                    modifier = Modifier
                        .padding(start = 16.dp, top = 16.dp)
                        .align(Alignment.Start),
                    color = Color.Green,
                    style = TextStyle(fontSize = 18.sp, fontWeight = FontWeight.Bold)
                )
            }
        }

        Text(
            text = "Регистрация!",
            style = TextStyle(fontSize = 32.sp, fontWeight = FontWeight.Bold),
            modifier = Modifier.height(60.dp).padding(bottom = 20.dp)
        )

        Text(
            text = "Заполните Свои данные или продолжите через социальные медиа",
            modifier = Modifier
                .fillMaxWidth()
                .padding(bottom = 20.dp),
            style = TextStyle(fontSize = 16.sp),
            textAlign = TextAlign.Center,
            maxLines = 2
        )

        Text(text = "Ваше имя", modifier = Modifier.padding(end = 255.dp))
        TextField(
            modifier = Modifier.width(300.dp).height(70.dp).padding(bottom = 16.dp),
            value = nameIn,
            onValueChange = { nameIn = it }
        )

        Text(text = "Email", modifier = Modifier.padding(end = 255.dp))
        TextField(
            modifier = Modifier.width(300.dp).height(70.dp).padding(bottom = 16.dp),
            value = emailIn,
            onValueChange = { emailIn = it }
        )

        Text(text = "Password", modifier = Modifier.padding(end = 225.dp))
        TextField(
            modifier = Modifier.width(300.dp).height(70.dp).padding(bottom = 16.dp),
            value = passwordIn,
            onValueChange = { passwordIn = it }
        )

        Button(
            modifier = Modifier.width(350.dp).height(50.dp),
            colors = androidx.compose.material3.ButtonDefaults.buttonColors(
                containerColor = Color(0xFF48B2E7),
                contentColor = Color.White
            ),
            onClick = { onReg(emailIn, passwordIn, nameIn) }
        ) {
            Text("Зарегистрироваться")
        }

        Row(
            modifier = Modifier
                .padding(top = 16.dp)
                .fillMaxWidth(),
            horizontalArrangement = Arrangement.Center
        ) {
            Text(
                text = "Есть аккаунт? ",
                style = TextStyle(fontSize = 16.sp, color = Color.Black)
            )

            ClickableText(
                text = buildAnnotatedString { append("Войти") },
                onClick = {
                    navController.navigate("auth_screen")
                },
                style = TextStyle(
                    fontSize = 16.sp,
                    color = Color.Black
                ),
            )
        }
    }
}


//@Composable
//fun RegistrationContent(viewModel: AuthScreenViewModel, navController: NavController){
//    val regState = viewModel.registrationScreenState.collectAsState()
//
//    if (regState.value.isSignUp) {
//        Text("Success Registration")
//    }
//
//    Column(
//        modifier = Modifier.fillMaxSize(),
//        horizontalAlignment = Alignment.CenterHorizontally,
//        verticalArrangement = Arrangement.Center
//    ) {
//        Text(
//            text = "Регистрация!",
//            style = TextStyle(fontSize = 32.sp, fontWeight = FontWeight.Bold),
//            modifier = Modifier.height(60.dp).padding(bottom = 20.dp)
//        )
//
//        Text(
//            text = "Заполните Свои данные или продолжите через социальные медиа",
//            modifier = Modifier
//                .fillMaxWidth()
//                .padding(bottom = 20.dp),
//            style = TextStyle(fontSize = 16.sp),
//            textAlign = TextAlign.Center,
//            maxLines = 2
//        )
//
////        Text(text = "Ваше имя", modifier = Modifier.padding(end = 255.dp))
////        TextField(
////            modifier = Modifier.width(300.dp).height(70.dp).padding(bottom = 16.dp),
////            value = regState.value.email,
////            onValueChange = {
////                viewModel.setEmail(it)
////            })
//
//        Text(text = "Email", modifier = Modifier.padding(end = 255.dp))
//        TextField(
//            modifier = Modifier.width(300.dp).height(70.dp).padding(bottom = 16.dp),
//            value = regState.value.email,
//            onValueChange = {
//                viewModel.setEmail(it, true)
//            })
//
//        Text(text = "Password", modifier = Modifier.padding(end = 225.dp))
//        TextField(
//            modifier = Modifier.width(300.dp).height(70.dp).padding(bottom = 16.dp),
//            value = regState.value.password,
//            onValueChange = {
//                viewModel.setPassword(it, true)
//            },
//            visualTransformation = PasswordVisualTransformation()
//        )
//
//        Button(
//            modifier = Modifier.width(350.dp).height(50.dp),
//            colors = androidx.compose.material3.ButtonDefaults.buttonColors(
//                containerColor = Color(0xFF48B2E7),
//                contentColor = Color.White
//            ),
//            onClick = {
//                viewModel.reg()
//            }) {
//            Text("Зарегестрироваться")
//        }
//
//        Row(
//            modifier = Modifier
//                .padding(top = 16.dp)
//                .fillMaxWidth(),
//            horizontalArrangement = Arrangement.Center
//        ) {
//            Text(
//                text = "Есть аккаунт? ",
//                style = TextStyle(fontSize = 16.sp, color = Color.Black)
//            )
//
//            ClickableText(
//                text = buildAnnotatedString { append("Войти") },
//                onClick = {
//                    navController.navigate("auth_screen")
//                },
//                style = TextStyle(
//                    fontSize = 16.sp,
//                    color = Color.Black
//                ),
//            )
//        }
//    }
//}