package com.example.testktor

import android.util.Log
import androidx.compose.material3.CircularProgressIndicator
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.rememberCoroutineScope
import androidx.compose.runtime.setValue
import androidx.compose.ui.Modifier
import androidx.compose.ui.tooling.preview.Preview
import com.example.testktor.ui.theme.TestKtorTheme
import io.ktor.client.HttpClient
import io.ktor.client.engine.android.Android
import io.ktor.client.request.get
import io.ktor.client.request.post
import io.ktor.client.request.setBody
import io.ktor.client.statement.HttpResponse
import io.ktor.client.statement.bodyAsText
import io.ktor.client.utils.EmptyContent.contentType
import io.ktor.http.ContentType
import io.ktor.http.contentType
import kotlinx.serialization.Serializable
import kotlinx.serialization.decodeFromString
import kotlinx.serialization.encodeToString
import kotlinx.serialization.json.Json
import java.sql.Time

//@Composable
//fun UserScreen(modifier: Modifier = Modifier, client: HttpClient) {
//    var users by remember { mutableStateOf<List<User>?>(null) }
//    var isLoading by remember { mutableStateOf(true) }
//    var errorMessage by remember { mutableStateOf<String?>(null) }
//
//    val scope = rememberCoroutineScope()
//
//    LaunchedEffect(Unit) {
//        try {
//            val fetchedUsers = getUsers(client)
//            users = fetchedUsers
//        } catch (e: Exception) {
//            errorMessage = "Error fetching users: ${e.localizedMessage}"
//            Log.e("UserScreen", "Error: ${e.localizedMessage}", e)
//        }
//        isLoading = false
//    }
//
//    if (isLoading) {
//        CircularProgressIndicator()
//    }
//
//    errorMessage?.let {
//        Text(text = it)
//    }
//
//    users?.let {
//        it.forEach { user ->
//            Text(text = "User: ${user.name}, ID: ${user.id}")
//        }
//    } ?: run {
//        Text(text = "No users found or failed to load.")
//    }
//}
//
//suspend fun getUsers(client: HttpClient): List<User> {
//    val response: HttpResponse = client.get("http://212.67.10.54:8080/users") {
//        contentType(ContentType.Application.Json)
//    }
//    val responseBody = response.bodyAsText()
//    Log.d("getUsers", "Response: $responseBody") // Логируем ответ сервера
//
//    val json = Json { ignoreUnknownKeys = true }
//
//    return try {
//        json.decodeFromString<List<User>>(responseBody) // Десериализуем в List<User>
//    } catch (e: Exception) {
//        Log.e("getUsers", "Error deserializing response", e)
//        throw e // Повторно выбрасываем ошибку, чтобы она была обработана в UserScreen
//    }
//}
//
//@Preview(showBackground = true)
//@Composable
//fun UserScreenPreview() {
//    TestKtorTheme {
//        UserScreen(client = HttpClient(Android))
//    }
//}

@Serializable
data class User(
    val id: Int,
    val name: String,
    val email: String,
    val password: String,
    val resetToken: String)

//@Composable
//fun UserScreen(modifier: Modifier = Modifier, client: HttpClient) {
//    var user by remember { mutableStateOf<User?>(null) }
//    var isLoading by remember { mutableStateOf(true) }
//    var errorMessage by remember { mutableStateOf<String?>(null) }
//
//    val scope = rememberCoroutineScope()
//
//    LaunchedEffect(Unit) {
//        try {
//            val fetchedUser = getUser(client)
//            user = fetchedUser
//        } catch (e: Exception) {
//            errorMessage = "Error fetching user: ${e.localizedMessage}"
//            Log.e("UserScreen", "Error: ${e.localizedMessage}", e)
//        }
//        isLoading = false
//    }
//
//    if (isLoading) {
//        CircularProgressIndicator()
//    }
//
//    errorMessage?.let {
//        Text(text = it)
//    }
//
//    user?.let {
//        Text(text = "User: ${it.email}, ID: ${it.id}")
//    } ?: run {
//        Text(text = "No user found or failed to load.")
//    }
//}

//suspend fun getUser(client: HttpClient): User {
//    val response: HttpResponse = client.get("http://10.0.2.2:8080/user") {
//        contentType(ContentType.Application.Json)
//    }
//    val responseBody = response.bodyAsText()
//    Log.d("getUser", "Response: $responseBody")
//
//    val json = Json { ignoreUnknownKeys = true }
//
//    val buba = json.decodeFromString<User>(responseBody)
//    Log.d("json", buba.email)
//
//    return try {
//        json.decodeFromString<User>(responseBody)
//    } catch (e: Exception) {
//        Log.e("getUser", "Error deserializing response", e)
//        throw e
//    }
//}

suspend fun authUser(client: HttpClient, email: String, password: String): Boolean {
    try {
        val response: HttpResponse = client.post("http://10.0.2.2:8080/login") {
            contentType(ContentType.Application.Json)
            setBody(Json.encodeToString(mapOf("email" to email, "password" to password)))
        }

        val responseBody = response.bodyAsText()
        Log.d("authUser", "Response: $responseBody")

        val json = Json { ignoreUnknownKeys = true }
        val responseMap = json.decodeFromString<Map<String, String>>(responseBody)

        return responseMap["message"] == "Вход успешен"
    } catch (e: Exception) {
        Log.e("authUser", "Error during login request", e)
        return false
    }
}

suspend fun regUser(client: HttpClient, email: String, password: String, name: String): Boolean{
    try{
        val response: HttpResponse = client.post("http://10.0.2.2:8080/register"){
            contentType(ContentType.Application.Json)
            setBody(Json.encodeToString(mapOf("name" to name, "email" to email, "password" to password)))
        }

        val responseBody = response.bodyAsText()
        Log.d("regUser", "Response: $responseBody")

        val json = Json { ignoreUnknownKeys = true }
        val responseMap = json.decodeFromString<Map<String, String>>(responseBody)

        return responseMap["message"] == "Регистрация успешна"
    } catch (e: Exception){
        Log.e("regUser", "Error during registration request", e)
        return false
    }
}

suspend fun forgotPassword(client: HttpClient, email: String): Boolean{
    try{
        val response: HttpResponse = client.post("http://10.0.2.2:8080/forgot-password"){
            contentType(ContentType.Application.Json)
            setBody(Json.encodeToString(mapOf("email" to email)))
        }

        val responseBody = response.bodyAsText()
        Log.d("forgotPassword", "Response: $responseBody")

        val json = Json { ignoreUnknownKeys = true }
        val responseMap = json.decodeFromString<Map<String, String>>(responseBody)

        return responseMap["message"] == "Код на восстановление пароля отправлен"
    } catch (e: Exception){
        Log.e("forgotPassword", "Error during forgotting password", e)
        return false
    }
}

suspend fun resetPassword(client: HttpClient, code: String, newPassword: String): Boolean{
    try{
        val response: HttpResponse = client.post("http://10.0.2.2:8080/reset-password"){
            contentType(ContentType.Application.Json)
            setBody(Json.encodeToString(mapOf("code" to code, "newPassword" to newPassword)))
        }

        val responseBody = response.bodyAsText()
        Log.d("resetPassword", "Response: $responseBody")

        val json = Json { ignoreUnknownKeys = true }
        val responseMap = json.decodeFromString<Map<String, String>>(responseBody)

        return responseMap["message"] == "Пароль успешно изменён"
    } catch (e: Exception){
        Log.e("resetPassword", "Error during resetting password", e)
        return false
    }
}

//@Preview(showBackground = true)
//@Composable
//fun UserScreenPreview() {
//    TestKtorTheme {
//        UserScreen(client = HttpClient(Android))
//    }
//}